..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Handlers
--------

.. automodule:: invenio_oauthclient.handlers
   :members:

Models
------

.. automodule:: invenio_oauthclient.models
   :members:

Views
-----

.. automodule:: invenio_oauthclient.views
   :members:

Client
~~~~~~

.. automodule:: invenio_oauthclient.views.client
   :members:

Settings
~~~~~~~~

.. automodule:: invenio_oauthclient.views.settings
   :members:


Signals
-------

.. automodule:: invenio_oauthclient.signals
   :members:

Utils
-----

.. automodule:: invenio_oauthclient.utils
   :members:

Errors
------

.. automodule:: invenio_oauthclient.errors
   :members:
